@@ -35,29 +35,91 @@
 
 namespace QuantLib {
 
+//===========================================================================//
+//                              IborCouponPricer                             //
+//===========================================================================//
+
+    IborCouponPricer::IborCouponPricer(
+            Handle<OptionletVolatilityStructure> v,
+            boost::optional<bool> useIndexedCoupon)
+        : capletVol_(std::move(v)),
+          useIndexedCoupon_(useIndexedCoupon ?
+                            *useIndexedCoupon :
+                            !IborCoupon::Settings::instance().usingAtParCoupons()) {
+        registerWith(capletVol_);
+    }
+
+    void IborCouponPricer::initializeCachedData(const IborCoupon& coupon) const {
+
+        if(coupon.cachedDataIsInitialized_)
+            return;
+
+        coupon.fixingValueDate_ = coupon.iborIndex()->fixingCalendar().advance(
+            coupon.fixingDate_, coupon.iborIndex()->fixingDays(), Days);
+        coupon.fixingMaturityDate_ = coupon.iborIndex()->maturityDate(coupon.fixingValueDate_);
+
+        if (useIndexedCoupon_) {
+            coupon.fixingEndDate_ = coupon.fixingMaturityDate_;
+        } else {
+            if (coupon.isInArrears_)
+                coupon.fixingEndDate_ = coupon.fixingMaturityDate_;
+            else { // par coupon approximation
+                Date nextFixingDate = coupon.iborIndex()->fixingCalendar().advance(
+                    coupon.accrualEndDate(), -static_cast<Integer>(coupon.fixingDays_), Days);
+                coupon.fixingEndDate_ = coupon.iborIndex()->fixingCalendar().advance(
+                    nextFixingDate, coupon.iborIndex()->fixingDays(), Days);
+                // make sure the estimation period contains at least one day
+                coupon.fixingEndDate_ =
+                    std::max(coupon.fixingEndDate_, coupon.fixingValueDate_ + 1);
+            }
+        }
+
+        coupon.spanningTime_ = coupon.iborIndex()->dayCounter().yearFraction(
+            coupon.fixingValueDate_, coupon.fixingEndDate_);
+
+        QL_REQUIRE(coupon.spanningTime_ > 0.0,
+                   "\n cannot calculate forward rate between "
+                       << coupon.fixingValueDate_ << " and " << coupon.fixingEndDate_
+                       << ":\n non positive time (" << coupon.spanningTime_ << ") using "
+                       << coupon.iborIndex()->dayCounter().name() << " daycounter");
+
+        coupon.spanningTimeIndexMaturity_ = coupon.iborIndex()->dayCounter().yearFraction(
+            coupon.fixingValueDate_, coupon.fixingMaturityDate_);
+
+        coupon.cachedDataIsInitialized_ = true;
+    }
+
+    void IborCouponPricer::initialize(const FloatingRateCoupon& coupon) {
+        coupon_ = dynamic_cast<const IborCoupon *>(&coupon);
+        QL_REQUIRE(coupon_, "IborCouponPricer: expected IborCoupon");
+
+        initializeCachedData(*coupon_);
+
+        index_ = coupon_->iborIndex();
+        gearing_ = coupon_->gearing();
+        spread_ = coupon_->spread();
+        accrualPeriod_ = coupon_->accrualPeriod();
+        QL_REQUIRE(accrualPeriod_ != 0.0, "null accrual period");
+
+        fixingDate_ = coupon_->fixingDate_;
+        fixingValueDate_ = coupon_->fixingValueDate_;
+        fixingMaturityDate_ = coupon_->fixingMaturityDate_;
+        spanningTime_ = coupon_->spanningTime_;
+        spanningTimeIndexMaturity_ = coupon_->spanningTimeIndexMaturity_;
+    }
+
+
 //===========================================================================//
 //                              BlackIborCouponPricer                        //
 //===========================================================================//
 
     void BlackIborCouponPricer::initialize(const FloatingRateCoupon& coupon) {
 
-        gearing_ = coupon.gearing();
-        spread_ = coupon.spread();
-        accrualPeriod_ = coupon.accrualPeriod();
-        QL_REQUIRE(accrualPeriod_ != 0.0, "null accrual period");
+        IborCouponPricer::initialize(coupon);
 
-        index_ = ext::dynamic_pointer_cast<IborIndex>(coupon.index());
-        if (!index_) {
-            // check if the coupon was right
-            const auto* c = dynamic_cast<const IborCoupon*>(&coupon);
-            QL_REQUIRE(c, "IborCoupon required");
-            // coupon was right, index is not
-            QL_FAIL("IborIndex required");
-        }
-        Handle<YieldTermStructure> rateCurve =
-                                            index_->forwardingTermStructure();
+        Handle<YieldTermStructure> rateCurve = index_->forwardingTermStructure();
 
-        Date paymentDate = coupon.date();
+        Date paymentDate = coupon_->date();
         if (paymentDate > rateCurve->referenceDate())
             discount_ = rateCurve->discount(paymentDate);
         else
@@ -65,13 +127,11 @@ namespace QuantLib {
 
         spreadLegValue_ = spread_ * accrualPeriod_ * discount_;
 
-        coupon_ = &coupon;
     }
 
     Real BlackIborCouponPricer::optionletPrice(Option::Type optionType,
                                                Real effStrike) const {
-        Date fixingDate = coupon_->fixingDate();
-        if (fixingDate <= Settings::instance().evaluationDate()) {
+        if (fixingDate_ <= Settings::instance().evaluationDate()) {
             // the amount is determined
             Real a, b;
             if (optionType==Option::Call) {
@@ -87,7 +147,7 @@ namespace QuantLib {
             QL_REQUIRE(!capletVolatility().empty(),
                        "missing optionlet volatility");
             Real stdDev =
-                std::sqrt(capletVolatility()->blackVariance(fixingDate,
+                std::sqrt(capletVolatility()->blackVariance(fixingDate_,
                                                             effStrike));
             Real shift = capletVolatility()->displacement();
             bool shiftedLn =
@@ -114,9 +174,9 @@ namespace QuantLib {
         // lognormal method is more accurate in this regard.
         if ((!coupon_->isInArrears() && timingAdjustment_ == Black76))
             return fixing;
-        Date d1 = coupon_->fixingDate();
-        Date d2 = index_->valueDate(d1);
-        Date d3 = index_->maturityDate(d2);
+        const Date& d1 = fixingDate_;
+        const Date& d2 = fixingValueDate_;
+        const Date& d3 = fixingMaturityDate_;
         if (coupon_->date() == d3)
             return fixing;
 
@@ -126,7 +186,7 @@ namespace QuantLib {
         // no variance has accumulated, so the convexity is zero
         if (d1 <= referenceDate)
             return fixing;
-        Time tau = index_->dayCounter().yearFraction(d2, d3);
+        const Time& tau = spanningTimeIndexMaturity_;
         Real variance = capletVolatility()->blackVariance(d1, fixing);
 
         Real shift = capletVolatility()->displacement();
@@ -140,8 +200,8 @@ namespace QuantLib {
 
         if (timingAdjustment_ == BivariateLognormal) {
             QL_REQUIRE(!correlation_.empty(), "no correlation given");
-            Date d4 = coupon_->date();
-            Date d5 = d4 >= d3 ? d3 : d2;
+            const Date& d4 = coupon_->date();
+            const Date& d5 = d4 >= d3 ? d3 : d2;
             Time tau2 = index_->dayCounter().yearFraction(d5, d4);
             if (d4 >= d3)
                 adjustment = 0.0;
