@@ -65,10 +65,8 @@ namespace inflation_cpi_bond_test {
             Date maturity = datum.date;
             Handle<Quote> quote(ext::shared_ptr<Quote>(
                                 new SimpleQuote(datum.rate/100.0)));
-            ext::shared_ptr<Helper> h(
-                      new ZeroCouponInflationSwapHelper(quote, observationLag,
-                                                        maturity, calendar,
-                                                        bdc, dc, ii, yTS));
+            ext::shared_ptr<Helper> h(new ZeroCouponInflationSwapHelper(
+                quote, observationLag, maturity, calendar, bdc, dc, ii, CPI::AsIndex, yTS));
             instruments.push_back(h);
         }
         return instruments;
@@ -101,7 +99,7 @@ namespace inflation_cpi_bond_test {
             Date today(25, November, 2009);
             evaluationDate = calendar.adjust(today);
             Settings::instance().evaluationDate() = evaluationDate;
-            dayCounter = ActualActual();
+            dayCounter = ActualActual(ActualActual::ISDA);
 
             Date from(20, July, 2007);
             Date to(20, November, 2009);
@@ -209,11 +207,7 @@ void InflationCPIBondTest::testCleanPrice() {
 
     ext::shared_ptr<DiscountingBondEngine> engine(
                                  new DiscountingBondEngine(common.yTS));
-    ext::shared_ptr<InflationCouponPricer> pricer =
-        ext::make_shared<CPICouponPricer>(common.yTS);
-
     bond.setPricingEngine(engine);
-    setCouponPricer(bond.cashflows(), pricer);
 
     Real storedPrice = 383.01816406;
     Real calculated = bond.cleanPrice();
